import { FieldType } from "@saleor/components/Filter";
import { PluginConfigurationType } from "@saleor/graphql";
import {
  createFilterStructure,
  PluginFilterKeys
} from "@saleor/plugins/components/PluginsListPage";
import { PluginListUrlFilters } from "@saleor/plugins/urls";
import { getFilterQueryParams } from "@saleor/utils/filters";
import { stringifyQs } from "@saleor/utils/urls";
import { getExistingKeys } from "@test/filters";
import { config } from "@test/intl";
import { createIntl } from "react-intl";

import { getFilterQueryParam, getFilterVariables } from "./filters";

describe("Filtering query params", () => {
  it("should be empty object if no params given", () => {
    const params: PluginListUrlFilters = {};
    const filterVariables = getFilterVariables(params);

    expect(getExistingKeys(filterVariables)).toHaveLength(0);
  });

  it("should not be empty object if params given", () => {
    const params: PluginListUrlFilters = {
      type: PluginConfigurationType.GLOBAL
    };
    const filterVariables = getFilterVariables(params);

    expect(getExistingKeys(filterVariables)).toHaveLength(1);
  });
});

describe("Filtering URL params", () => {
  const intl = createIntl(config);

  const filters = createFilterStructure(intl, {
    isActive: {
      active: false,
      value: true
    },
    channels: {
      active: false,
      choices: [],
      displayValues: [],
      initialSearch: "",
      hasMore: false,
      loading: false,
      onFetchMore: () => undefined,
      onSearchChange: () => undefined,
      value: []
    },
    status: {
      active: false,
      value: false
    },
    type: {
      active: false,
      value: PluginConfigurationType.GLOBAL
    }
  });

  it("should be empty if no active filters", () => {
    const filterQueryParams = getFilterQueryParams(
      filters,
      getFilterQueryParam
    );

    expect(getExistingKeys(filterQueryParams)).toHaveLength(0);
  });

  it("should not be empty if active filters are present", () => {
    const filterQueryParams = getFilterQueryParams(
      [
        {
          name: PluginFilterKeys.active,
          type: FieldType.options,
          label: "Active",
          multiple: false,
          active: true,
          value: ["true"]
        },
        {
          name: PluginFilterKeys.type,
          type: FieldType.options,
          label: "Configuration type",
          multiple: false,
          active: true,
          value: [PluginConfigurationType.GLOBAL]
        }
      ],
      getFilterQueryParam
    );

    expect(filterQueryParams).toMatchSnapshot();
    expect(stringifyQs(filterQueryParams)).toMatchSnapshot();
  });
});
